# Generated by Django 2.2.20 on 2021-04-17 19:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0122_auto_20210411_1902'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='lens_model_name',
            field=models.CharField(blank=True, help_text='Model name of this lens', max_length=45, null=True, verbose_name='lens model'),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this camera model', on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer', verbose_name='manufacturer'),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='mount',
            field=models.ForeignKey(blank=True, help_text='Lens mount used by this camera model', limit_choices_to={'purpose': 'Camera'}, null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Mount', verbose_name='mount'),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='lens_model_name',
            field=models.CharField(blank=True, help_text='Model name of this lens', max_length=45, null=True, verbose_name='lens model'),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='manufacturer',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='Manufacturer of this camera model', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='schema.Manufacturer', verbose_name='manufacturer'),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='mount',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='Lens mount used by this camera model', limit_choices_to={'purpose': 'Camera'}, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='schema.Mount', verbose_name='mount'),
        ),
    ]



# Generated by Django 2.2 on 2020-03-21 21:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0037_auto_20200321_2101'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='cameramodel',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='cameramodel',
            constraint=models.UniqueConstraint(fields=(
                'manufacturer', 'model', 'disambiguation'), name='cameramodel_unique_name'),
        ),
    ]



# Generated by Django 2.2.23 on 2021-07-16 19:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0126_sphinxdocs'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='accessory',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_acce_owner_i_064684_idx'),
        ),
        migrations.AddIndex(
            model_name='archive',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_arch_owner_i_1e0470_idx'),
        ),
        migrations.AddIndex(
            model_name='battery',
            index=models.Index(fields=['slug'], name='schema_batt_slug_5185f7_idx'),
        ),
        migrations.AddIndex(
            model_name='bulkfilm',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_bulk_owner_i_4c6b52_idx'),
        ),
        migrations.AddIndex(
            model_name='camera',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_came_owner_i_131481_idx'),
        ),
        migrations.AddIndex(
            model_name='cameramodel',
            index=models.Index(fields=['slug'], name='schema_came_slug_76fba7_idx'),
        ),
        migrations.AddIndex(
            model_name='developer',
            index=models.Index(fields=['slug'], name='schema_deve_slug_208c0a_idx'),
        ),
        migrations.AddIndex(
            model_name='enlarger',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_enla_owner_i_f376cb_idx'),
        ),
        migrations.AddIndex(
            model_name='enlargermodel',
            index=models.Index(fields=['slug'], name='schema_enla_slug_cdd708_idx'),
        ),
        migrations.AddIndex(
            model_name='film',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_film_owner_i_262269_idx'),
        ),
        migrations.AddIndex(
            model_name='filmstock',
            index=models.Index(fields=['slug'], name='schema_film_slug_77941c_idx'),
        ),
        migrations.AddIndex(
            model_name='flash',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_flas_owner_i_90ed5d_idx'),
        ),
        migrations.AddIndex(
            model_name='flashmodel',
            index=models.Index(fields=['slug'], name='schema_flas_slug_35f243_idx'),
        ),
        migrations.AddIndex(
            model_name='lens',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_lens_owner_i_ef47ee_idx'),
        ),
        migrations.AddIndex(
            model_name='lensmodel',
            index=models.Index(fields=['slug'], name='schema_lens_slug_1b7268_idx'),
        ),
        migrations.AddIndex(
            model_name='manufacturer',
            index=models.Index(fields=['slug'], name='schema_manu_slug_fd5a47_idx'),
        ),
        migrations.AddIndex(
            model_name='manufacturer',
            index=models.Index(fields=['country', 'country'], name='schema_manu_country_abce90_idx'),
        ),
        migrations.AddIndex(
            model_name='mount',
            index=models.Index(fields=['slug'], name='schema_moun_slug_d93c9e_idx'),
        ),
        migrations.AddIndex(
            model_name='mountadapter',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_moun_owner_i_56f606_idx'),
        ),
        migrations.AddIndex(
            model_name='negative',
            index=models.Index(fields=['slug'], name='schema_nega_slug_146056_idx'),
        ),
        migrations.AddIndex(
            model_name='negative',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_nega_owner_i_a88607_idx'),
        ),
        migrations.AddIndex(
            model_name='order',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_orde_owner_i_c53670_idx'),
        ),
        migrations.AddIndex(
            model_name='person',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_pers_owner_i_e452fe_idx'),
        ),
        migrations.AddIndex(
            model_name='print',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_prin_owner_i_235fbb_idx'),
        ),
        migrations.AddIndex(
            model_name='teleconverter',
            index=models.Index(fields=['owner', 'id_owner'], name='schema_tele_owner_i_80ab0e_idx'),
        ),
        migrations.AddIndex(
            model_name='teleconvertermodel',
            index=models.Index(fields=['slug'], name='schema_tele_slug_6eab52_idx'),
        ),
        migrations.AddIndex(
            model_name='toner',
            index=models.Index(fields=['slug'], name='schema_tone_slug_3724e1_idx'),
        ),
    ]



# Generated by Django 2.2.9 on 2020-03-17 13:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0029_remove_paperstock_tonable'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paperstock',
            name='finish',
            field=models.CharField(blank=True, choices=[('Matt', 'Matt'), ('Gloss', 'Gloss'), ('Satin', 'Satin'), ('Semi gloss', 'Semi gloss'), (
                'Pearl', 'Pearl'), ('Lustre', 'Lustre')], help_text='The finish of the paper surface', max_length=25, null=True),
        ),
    ]



from __future__ import unicode_literals
from django.db import migrations, models
from slugify import UniqueSlugify


def addManufacturer(apps, schema_editor):
    ExistingRecords = apps.get_model('schema', 'manufacturer')
    custom_slugify_unique = UniqueSlugify(to_lower=True)
    for record in ExistingRecords.objects.all():
        record.slug = custom_slugify_unique(record.name)
        record.save()


def addBattery(apps, schema_editor):
    ExistingRecords = apps.get_model('schema', 'battery')
    custom_slugify_unique = UniqueSlugify(to_lower=True)
    for record in ExistingRecords.objects.all():
        record.slug = custom_slugify_unique(record.name)
        record.save()


def addMount(apps, schema_editor):
    ExistingRecords = apps.get_model('schema', 'mount')
    custom_slugify_unique = UniqueSlugify(to_lower=True)
    for record in ExistingRecords.objects.all():
        record.slug = custom_slugify_unique(record.mount)
        record.save()


def addToner(apps, schema_editor):
    ExistingRecords = apps.get_model('schema', 'toner')
    custom_slugify_unique = UniqueSlugify(to_lower=True)
    for record in ExistingRecords.objects.all():
        record.slug = custom_slugify_unique(
            f"{record.manufacturer.name} {record.name}"
        )
        record.save()


def addFilmstock(apps, schema_editor):
    ExistingRecords = apps.get_model('schema', 'filmstock')
    custom_slugify_unique = UniqueSlugify(to_lower=True)
    for record in ExistingRecords.objects.all():
        record.slug = custom_slugify_unique(
            f"{record.manufacturer.name} {record.name}"
        )
        record.save()


def addDeveloper(apps, schema_editor):
    ExistingRecords = apps.get_model('schema', 'developer')
    custom_slugify_unique = UniqueSlugify(to_lower=True)
    for record in ExistingRecords.objects.all():
        record.slug = custom_slugify_unique(
            f"{record.manufacturer.name} {record.name}"
        )
        record.save()


def addLensmodel(apps, schema_editor):
    ExistingRecords = apps.get_model('schema', 'lensmodel')
    custom_slugify_unique = UniqueSlugify(to_lower=True)
    for record in ExistingRecords.objects.all():
        record.slug = custom_slugify_unique(
            f"{record.manufacturer.name} {record.model} {str(record.disambiguation or '')}"
        )
        record.save()


class Migration(migrations.Migration):
    dependencies = [
        ('schema', '0040_auto_20200321_2330'),
    ]
    operations = [
        migrations.RunPython(
            addManufacturer, reverse_code=migrations.RunPython.noop),
        migrations.RunPython(
            addBattery, reverse_code=migrations.RunPython.noop),
        migrations.RunPython(addMount, reverse_code=migrations.RunPython.noop),
        migrations.RunPython(addToner, reverse_code=migrations.RunPython.noop),
        migrations.RunPython(
            addFilmstock, reverse_code=migrations.RunPython.noop),
        migrations.RunPython(
            addDeveloper, reverse_code=migrations.RunPython.noop),
        migrations.RunPython(
            addLensmodel, reverse_code=migrations.RunPython.noop),
    ]



from django import template
register = template.Library()

@register.filter
def verbose_name(obj):
    return obj._meta.verbose_name

@register.filter
def verbose_name_plural(obj):
    return obj._meta.verbose_name_plural

@register.filter
def model_name(obj):
    return obj._meta.model_name

@register.filter
def model_list(obj):
    return 'schema:' + obj._meta.model_name + '-list'

@register.filter
def model_add(obj):
    return 'schema:' + obj._meta.model_name + '-create'



# Generated by Django 2.2.17 on 2020-12-16 20:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0115_auto_20201212_2131'),
    ]

    operations = [
        migrations.AlterField(
            model_name='negative',
            name='flash',
            field=models.BooleanField(default=False, help_text='Whether flash was used'),
        ),
    ]



from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0125_auto_20210517_2102'),
        ('sphinxdoc', '0001_initial'),
    ]

    operations = [
        migrations.RunSQL(
            sql=[("INSERT INTO sphinxdoc_project (id, name, slug, path) VALUES (1, 'CameraHub', 'camerahub', 'docs');")],
            reverse_sql=[("DELETE FROM sphinxdoc_project where id=1;")],
        )
    ]



from django.conf import settings
from django.contrib.sites.models import Site

class DynamicSiteDomainMiddleware:

    def __init__(self, get_response):
        self.get_response = get_response
        # One-time configuration and initialization.

    def __call__(self, request):
        try:
            current_site = Site.objects.get(domain=request.get_host())
        except Site.DoesNotExist:
            current_site = Site.objects.get(id=settings.DEFAULT_SITE_ID)

        request.current_site = current_site
        settings.SITE_ID = current_site.id


        response = self.get_response(request)
        return response



# Generated by Django 2.2.14 on 2020-08-28 20:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0080_populate_shutter'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='shutter_speeds',
        ),
    ]



# Generated by Django 2.2.4 on 2020-01-10 17:36

import autosequence.fields
from django.db import migrations


class Migration(migrations.Migration):

    replaces = [('schema', '0019_auto_20200110_1728'),
                ('schema', '0020_auto_20200110_1734')]

    dependencies = [
        ('schema', '0018_auto_20191217_2303'),
    ]

    operations = [
        migrations.AlterField(
            model_name='archive',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='accessory',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='bulkfilm',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='camera',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='enlarger',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='film',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='filter',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='flash',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='lens',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='mountadapter',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='negative',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='order',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='person',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='print',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='repair',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='scan',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='series',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='teleconverter',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterUniqueTogether(
            name='accessory',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='archive',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='bulkfilm',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='camera',
            unique_together={('cameramodel', 'serial')},
        ),
        migrations.AlterUniqueTogether(
            name='enlarger',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='film',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='filter',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='flash',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='lens',
            unique_together={('lensmodel', 'serial')},
        ),
        migrations.AlterUniqueTogether(
            name='mountadapter',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='negative',
            unique_together={('film', 'frame')},
        ),
        migrations.AlterUniqueTogether(
            name='order',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='person',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='print',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='repair',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='scan',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='series',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='teleconverter',
            unique_together=set(),
        ),
    ]



# Generated by Django 2.2.16 on 2020-10-21 14:38

from django.db import migrations
import geoposition.fields


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0091_auto_20201013_0929'),
    ]

    operations = [
        migrations.AddField(
            model_name='negative',
            name='location',
            field=geoposition.fields.GeopositionField(blank=True, help_text='Location where the picture was taken', max_length=42, null=True),
        ),
    ]



# Generated by Django 2.2.16 on 2020-10-12 18:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0089_auto_20201009_1926'),
    ]

    operations = [
        migrations.AddField(
            model_name='film',
            name='status',
            field=models.CharField(choices=[('Available', 'Available'), ('Loaded', 'Loaded'), ('Developed', 'Developed'), ('Archived', 'Archived')], default='Available', help_text='Status of this film', max_length=9),
        ),
    ]



# Generated by Django 2.2 on 2020-03-04 20:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0022_auto_20200229_1954'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='meter_min_ev',
            field=models.IntegerField(
                blank=True, help_text='Lowest EV/LV the built-in meter supports', null=True, verbose_name='Min EV'),
        ),
    ]



# Generated by Django 2.2.9 on 2020-03-17 13:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0028_cameramodel_x_sync'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='paperstock',
            name='tonable',
        ),
    ]



# Generated by Django 2.2.23 on 2021-07-16 19:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0127_auto_20210716_1911'),
    ]

    operations = [
        migrations.AddField(
            model_name='person',
            name='type',
            field=models.CharField(blank=True, choices=[('Individual', 'Individual'), ('Business', 'Business')], help_text='Type of person or business', max_length=25, null=True),
        ),
        migrations.AlterField(
            model_name='person',
            name='name',
            field=models.CharField(help_text='Name of the person or business', max_length=45, unique=True),
        ),
    ]



# Generated by Django 2.2.14 on 2020-09-05 19:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0083_auto_20200904_2154'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cameramodel',
            old_name='power_drive',
            new_name='internal_power_drive',
        ),
        migrations.RenameField(
            model_name='historicalcameramodel',
            old_name='power_drive',
            new_name='internal_power_drive',
        ),
    ]



# Generated by Django 2.2.14 on 2020-09-22 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0084_auto_20200905_1952'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicallensmodel',
            name='perspective_control',
            field=models.BooleanField(blank=True, help_text='Whether this lens has perspective control / tilt-shift', null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='perspective_control',
            field=models.BooleanField(blank=True, help_text='Whether this lens has perspective control / tilt-shift', null=True),
        ),
    ]



# Generated by Django 2.2.20 on 2021-05-17 21:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0124_auto_20210428_1918'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='focus_type',
            field=models.CharField(blank=True, choices=[('Autofocus', 'Autofocus'), ('Fixed focus', 'Fixed focus'), ('Zone_focus', 'Manual focus (zone focus)'), ('Rangefinder', 'Manual focus (rangefinder)'), ('SLR', 'Manual focus (SLR)'), ('TLR', 'Manual focus (TLR)'), ('View_camera', 'Manual focus (view camera)')], help_text='Focus type used on this camera model', max_length=25, null=True),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='focus_type',
            field=models.CharField(blank=True, choices=[('Autofocus', 'Autofocus'), ('Fixed focus', 'Fixed focus'), ('Zone_focus', 'Manual focus (zone focus)'), ('Rangefinder', 'Manual focus (rangefinder)'), ('SLR', 'Manual focus (SLR)'), ('TLR', 'Manual focus (TLR)'), ('View_camera', 'Manual focus (view camera)')], help_text='Focus type used on this camera model', max_length=25, null=True),
        ),
    ]



# Generated by Django 2.2.16 on 2020-11-10 22:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0102_slugs'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cameramodel',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='historicalcameramodel',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='historicallensmodel',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='historicalmanufacturer',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='lensmodel',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='manufacturer',
            old_name='url',
            new_name='linkurl',
        ),
    ]



# Generated by Django 2.2.16 on 2020-10-22 13:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0093_auto_20201021_1614'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for camera models with the same name', max_length=45),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for camera models with the same name', max_length=45),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for lens models with the same name', max_length=45),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for lens models with the same name', max_length=45),
        ),
    ]



# Generated by Django 2.2.16 on 2020-10-24 19:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0095_auto_20201023_2111'),
    ]

    operations = [
        migrations.AlterField(
            model_name='camera',
            name='own',
            field=models.BooleanField(default=True, help_text='Whether the camera is currently in your collection'),
        ),
        migrations.AlterField(
            model_name='flash',
            name='own',
            field=models.BooleanField(default=True, help_text='Whether the flash is currently in your collection'),
        ),
        migrations.AlterField(
            model_name='lens',
            name='own',
            field=models.BooleanField(default=True, help_text='Whether the lens is currently in your collection'),
        ),
        migrations.AlterField(
            model_name='print',
            name='own',
            field=models.BooleanField(default=True, help_text='Whether the print is currently in your collection'),
        ),
    ]



# Generated by Django 2.2.17 on 2020-11-26 13:50

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0107_auto_20201124_1955'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Flash',
            new_name='FlashModel',
        ),
    ]



# Generated by Django 2.2.14 on 2020-08-18 21:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0072_auto_20200816_2047'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalnegativesize',
            name='diagonal',
            field=models.DecimalField(blank=True, decimal_places=1, editable=False, help_text='Diagonal of the negative size in mm', max_digits=5, null=True),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='diagonal',
            field=models.DecimalField(blank=True, decimal_places=1, editable=False, help_text='Diagonal of the negative size in mm', max_digits=5, null=True),
        ),
    ]



# Generated by Django 2.2 on 2020-03-17 21:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0033_auto_20200317_1416'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='filter',
            options={'ordering': ['type'], 'verbose_name_plural': 'filters'},
        ),
        migrations.RemoveField(
            model_name='filter',
            name='id_owner',
        ),
        migrations.RemoveField(
            model_name='filter',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='filter',
            name='owner',
        ),
        migrations.RemoveField(
            model_name='filter',
            name='qty',
        ),
        migrations.RemoveField(
            model_name='filter',
            name='thread',
        ),
    ]



# Generated by Django 2.2.18 on 2021-02-21 22:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0119_auto_20210216_2046'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='link',
            field=models.URLField(blank=True, help_text='Link to more information about this camera model', null=True),
        ),
        migrations.AlterField(
            model_name='enlargermodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='flashmodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='link',
            field=models.URLField(blank=True, help_text='Link to more information about this camera model', null=True),
        ),
        migrations.AlterField(
            model_name='historicalenlargermodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicalflashmodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='diagram_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this diagram', null=True),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='link',
            field=models.URLField(blank=True, help_text='Link to more information about this lens', null=True),
        ),
        migrations.AlterField(
            model_name='historicalmanufacturer',
            name='link',
            field=models.URLField(blank=True, help_text='Link to the manufacturers main website', max_length=45, null=True),
        ),
        migrations.AlterField(
            model_name='historicalteleconvertermodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='diagram_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this diagram', null=True),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='link',
            field=models.URLField(blank=True, help_text='Link to more information about this lens', null=True),
        ),
        migrations.AlterField(
            model_name='manufacturer',
            name='link',
            field=models.URLField(blank=True, help_text='Link to the manufacturers main website', max_length=45, null=True),
        ),
        migrations.AlterField(
            model_name='teleconvertermodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
    ]



# Generated by Django 2.2.4 on 2019-10-16 10:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0010_auto_20191016_1023'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='digital',
        ),
        migrations.RemoveField(
            model_name='flash',
            name='dslr_safe',
        ),
        migrations.RemoveField(
            model_name='format',
            name='digital',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='digital_only',
        ),
    ]



# Generated by Django 2.2.12 on 2020-05-14 09:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0054_auto_20200504_2104'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='recipient',
            field=models.ForeignKey(blank=True, help_text='Person who placed this order', null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Person'),
        ),
    ]



# Generated by Django 2.2.9 on 2020-03-05 10:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0025_convert_shoe_data'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='coldshoe',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='hotshoe',
        ),
    ]



# Generated by Django 2.2.14 on 2020-08-25 19:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0074_auto_20200820_2003'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='pc_sync',
            field=models.BooleanField(blank=True, help_text='Whether the camera has a PC sync socket for flash (sometimes known as a German socket)', null=True, verbose_name='PC sync'),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='pc_sync',
            field=models.BooleanField(blank=True, help_text='Whether the camera has a PC sync socket for flash (sometimes known as a German socket)', null=True, verbose_name='PC sync'),
        ),
    ]



from __future__ import unicode_literals
from django.db import migrations, models
from slugify import slugify


def addNegative(apps, schema_editor):
    negatives = apps.get_model('schema', 'negative')
    for record in negatives.objects.all():
        record.slug = slugify(str(record.film.id_owner) + '.' + str(record.frame), separator='.')
        record.save()

class Migration(migrations.Migration):
    dependencies = [
        ('schema', '0116_auto_20201216_2013'),
    ]
    operations = [
        migrations.RunPython(
            addNegative, reverse_code=migrations.RunPython.noop),

    ]



# Generated by Django 2.2.17 on 2020-11-26 22:51

import autosequence.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_currentuser.db.models.fields
import django_currentuser.middleware
import simple_history.models
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0003_taggeditem_add_unique_index'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0110_auto_20201126_2236'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='teleconvertermodel',
            options={'ordering': ['manufacturer', 'model'], 'verbose_name_plural': 'teleconverter models'},
        ),
        migrations.RemoveField(
            model_name='teleconvertermodel',
            name='id_owner',
        ),
        migrations.RemoveField(
            model_name='teleconvertermodel',
            name='owner',
        ),
        migrations.AddField(
            model_name='teleconvertermodel',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='teleconvertermodel',
            name='tags',
            field=taggit.managers.TaggableManager(blank=True, help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.CreateModel(
            name='Teleconverter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('id_owner', autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID')),
                ('owner', django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('teleconvertermodel', models.ForeignKey(help_text='Model of this teleconverter', on_delete=django.db.models.deletion.CASCADE, to='schema.TeleconverterModel')),
            ],
            options={
                'verbose_name_plural': 'teleconverters',
            },
        ),
        migrations.CreateModel(
            name='HistoricalTeleconverterModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('model', models.CharField(help_text='Model name of this teleconverter', max_length=45)),
                ('factor', models.DecimalField(blank=True, decimal_places=2, help_text='Magnification factor of this teleconverter (numerical part only, e.g. 1.4)', max_digits=4, null=True)),
                ('elements', models.PositiveIntegerField(blank=True, help_text='Number of optical elements used in this teleconverter', null=True)),
                ('groups', models.PositiveIntegerField(blank=True, help_text='Number of optical groups used in this teleconverter', null=True)),
                ('multicoated', models.BooleanField(blank=True, help_text='Whether this teleconverter is multi-coated', null=True)),
                ('slug', models.SlugField(editable=False, null=True)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('manufacturer', models.ForeignKey(blank=True, db_constraint=False, help_text='Manufacturer of this teleconverter', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='schema.Manufacturer')),
                ('mount', models.ForeignKey(blank=True, db_constraint=False, help_text='Lens mount used by this teleconverter', limit_choices_to={'purpose': 'Camera'}, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='schema.Mount')),
            ],
            options={
                'verbose_name': 'historical teleconverter model',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



# Generated by Django 2.2.16 on 2020-10-02 18:25

import collectionfield.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0086_auto_20200930_1924'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='other_names',
            field=collectionfield.models.fields.CollectionField(blank=True, help_text='Other model names that this camera may be known by, e.g. in other parts of the world. Separate with commas.', null=True),
        ),
        migrations.AddField(
            model_name='historicalcameramodel',
            name='other_names',
            field=collectionfield.models.fields.CollectionField(blank=True, help_text='Other model names that this camera may be known by, e.g. in other parts of the world. Separate with commas.', null=True),
        ),
    ]



# Generated by Django 2.2.17 on 2020-12-12 21:31

from django.db import migrations, models
import django.db.models.deletion
import versatileimagefield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0114_auto_20201211_2019'),
    ]

    operations = [
        migrations.AddField(
            model_name='enlargermodel',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Image of the enlarger model', null=True, upload_to=''),
        ),
        migrations.AddField(
            model_name='enlargermodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='enlargermodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AddField(
            model_name='flashmodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for flash models with the same name', max_length=45),
        ),
        migrations.AddField(
            model_name='flashmodel',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Image of the flash model', null=True, upload_to=''),
        ),
        migrations.AddField(
            model_name='flashmodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='flashmodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AddField(
            model_name='historicalenlargermodel',
            name='image',
            field=models.TextField(blank=True, help_text='Image of the enlarger model', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='historicalenlargermodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='historicalenlargermodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AddField(
            model_name='historicalflashmodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for flash models with the same name', max_length=45),
        ),
        migrations.AddField(
            model_name='historicalflashmodel',
            name='image',
            field=models.TextField(blank=True, help_text='Image of the flash model', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='historicalflashmodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='historicalflashmodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AddField(
            model_name='historicalteleconvertermodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for teleconverter models with the same name', max_length=45),
        ),
        migrations.AddField(
            model_name='historicalteleconvertermodel',
            name='image',
            field=models.TextField(blank=True, help_text='Image of the teleconverter model', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='historicalteleconvertermodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='historicalteleconvertermodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AddField(
            model_name='teleconvertermodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for teleconverter models with the same name', max_length=45),
        ),
        migrations.AddField(
            model_name='teleconvertermodel',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Image of the teleconverter model', null=True, upload_to=''),
        ),
        migrations.AddField(
            model_name='teleconvertermodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='teleconvertermodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AlterField(
            model_name='enlargermodel',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this enlarger', on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='flashmodel',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this flash', on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='teleconvertermodel',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this teleconverter', on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AddConstraint(
            model_name='flashmodel',
            constraint=models.UniqueConstraint(fields=('manufacturer', 'model', 'disambiguation'), name='flashmodel_unique_name'),
        ),
        migrations.AddConstraint(
            model_name='teleconvertermodel',
            constraint=models.UniqueConstraint(fields=('manufacturer', 'model', 'disambiguation'), name='teleconvertermodel_unique_name'),
        ),
    ]



from django.apps import AppConfig
from watson import search as watson


class SchemaConfig(AppConfig):
    name = 'schema'

    def ready(self):
        # Index public data for searching
        cameramodel = self.get_model("CameraModel")
        lensmodel = self.get_model("LensModel")
        battery = self.get_model("Battery")
        developer = self.get_model("Developer")
        filmstock = self.get_model("FilmStock")
        manufacturer = self.get_model("Manufacturer")
        mount = self.get_model("Mount")
        paperstock = self.get_model("PaperStock")
        toner = self.get_model("Toner")

        watson.register(cameramodel)
        watson.register(lensmodel)
        watson.register(battery)
        watson.register(developer)
        watson.register(filmstock)
        watson.register(manufacturer)
        watson.register(mount)
        watson.register(paperstock)
        watson.register(toner)



# Generated by Django 2.2.16 on 2020-10-24 19:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0096_auto_20201024_1941'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='camera',
            options={'ordering': ['-own', 'cameramodel__manufacturer', 'cameramodel__model', 'serial'], 'verbose_name_plural': 'cameras'},
        ),
        migrations.AlterModelOptions(
            name='lens',
            options={'ordering': ['-own', 'lensmodel__manufacturer', 'lensmodel__model', 'serial'], 'verbose_name_plural': 'lenses'},
        ),
    ]



# Generated by Django 2.2 on 2020-03-21 22:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0038_auto_20200321_2115'),
    ]

    operations = [
        migrations.AddField(
            model_name='battery',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='developer',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='mount',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='toner',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
    ]



# Generated by Django 2.2.9 on 2020-03-24 08:39

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_currentuser.db.models.fields
import django_currentuser.middleware


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0047_auto_20200323_2236'),
    ]

    operations = [
        migrations.AddField(
            model_name='battery',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='battery',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user,
                                                                       editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='battery_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='battery',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='battery',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='battery_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='developer',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='developer',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='developer_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='developer',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='developer',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='developer_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='filmstock_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='filmstock_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='flashprotocol',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='flashprotocol',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flashprotocol_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='flashprotocol',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='flashprotocol',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='flashprotocol_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='format',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='format',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user,
                                                                       editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='format_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='format',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='format',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='format_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='manufacturer_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='manufacturer_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mount',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='mount',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user,
                                                                       editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='mount_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mount',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='mount',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='mount_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='negativesize_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='negativesize_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='paperstock_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='paperstock_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='toner',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='toner',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user,
                                                                       editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='toner_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='toner',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='toner',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='toner_updated_by', to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 2.2.9 on 2020-03-05 10:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0023_auto_20200304_2020'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='shoe',
            field=models.CharField(blank=True, choices=[('No shoe', 'No shoe'), ('Hot shoe', 'Hot shoe'), (
                'Cold shoe', 'Cold shoe')], help_text='Type of flash/accessory shoe used on this camera model', max_length=9, null=True),
        ),
    ]



"""
Django settings for camerahub project.

Generated by 'django-admin startproject' using Django 2.1.10.

For more information on this file, see
https://docs.djangoproject.com/en/2.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.1/ref/settings/
"""

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/2.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = os.getenv('CAMERAHUB_SECRET_KEY', 'OverrideMe!')

# SECURITY WARNING: don't run with debug turned on in production!
if os.getenv('CAMERAHUB_PROD') == 'true':
    DEBUG = False
else:
    DEBUG = True

ALLOWED_HOSTS = ['*']

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.sites',
    'schema',
    'api',
    'djmoney',
    'django_tables2',
    'crispy_forms',
    'fullurl',
    'django_filters',
    'watson',
    'taggit',
    'django_prometheus',
    'simple_history',
    'django_social_share',
    'django_countries',
    'dal',
    'dal_select2',
    'bootstrap_datepicker_plus',
    'geoposition',
    'leaflet',
    'rest_framework',
    'drf_generators',
    'dbbackup',
    'star_ratings',
    'health_check',
    'health_check.db',
    'health_check.storage',
    'health_check.cache',
    'clear_cache',
    'speedinfo',
    'speedinfo.storage.database',
    'sphinxdoc',
    'haystack',
]

MIDDLEWARE = [
    'django_prometheus.middleware.PrometheusBeforeMiddleware',
    'django.middleware.cache.UpdateCacheMiddleware',
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django_currentuser.middleware.ThreadLocalUserMiddleware',
    'simple_history.middleware.HistoryRequestMiddleware',
    'camerahub.middleware.DynamicSiteDomainMiddleware',
    'speedinfo.middleware.ProfilerMiddleware',
    'django.middleware.cache.FetchFromCacheMiddleware',
    'django_prometheus.middleware.PrometheusAfterMiddleware',
]

ROOT_URLCONF = 'camerahub.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'templates')],
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.template.context_processors.media',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'django_settings_export.settings_export',
            ],
            'loaders': [
                'django.template.loaders.filesystem.Loader',
                'django.template.loaders.app_directories.Loader',
            ],
        },
    },
]

WSGI_APPLICATION = 'camerahub.wsgi.application'


# Database
# https://docs.djangoproject.com/en/2.1/ref/settings/#databases
# Configure databases by setting env vars CAMERAHUB_DB_*

DATABASES = {
    'default': {
        'ENGINE': os.getenv('CAMERAHUB_DB_ENGINE', 'django.db.backends.sqlite3'),
        'NAME': os.getenv('CAMERAHUB_DB_NAME', os.path.join(BASE_DIR, 'db', 'db.sqlite3')),
        'USER': os.getenv('CAMERAHUB_DB_USER'),
        'PASSWORD': os.getenv('CAMERAHUB_DB_PASS'),
        'HOST': os.getenv('CAMERAHUB_DB_HOST'),
        'PORT': os.getenv('CAMERAHUB_DB_PORT'),
    }
}

# Password validation
# https://docs.djangoproject.com/en/2.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/2.1/topics/i18n/

LANGUAGE_CODE = 'en-gb'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = False
USE_TZ = True

DATE_INPUT_FORMATS = ['%Y-%m-%d', ]
DATETIME_INPUT_FORMATS = ['%Y-%m-%d %H:%M:%S', '%Y-%m-%d %H:%M']
TIME_INPUT_FORMATS = ['%H:%M:%S', '%H:%M', ]

DATE_FORMAT = 'Y-m-d'
TIME_FORMAT = 'Y-m-d H:i'
SHORT_DATE_FORMAT = 'Y-m-d'
SHORT_DATETIME_FORMAT = 'Y-m-d H:i'

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.1/howto/static-files/

# Where to put static files when they are collected
STATIC_ROOT = os.path.join(BASE_DIR, "static")

# Where to serve static files from
STATIC_URL = '/static/'

# Where to store uploaded assets
MEDIA_ROOT = os.path.join(BASE_DIR, "media")

# Where to serve uploaded assets from
MEDIA_URL = '/media/'

# Add media to the list of static dirs
STATICFILES_DIRS = [
    os.path.join(BASE_DIR, 'media/'),
]

DJANGO_TABLES2_TEMPLATE = "django_tables2/bootstrap4.html"

LOGIN_REDIRECT_URL = 'schema:index'
LOGOUT_REDIRECT_URL = 'schema:index'

CRISPY_TEMPLATE_PACK = 'bootstrap4'

# Email support
DEFAULT_FROM_EMAIL = os.getenv('CAMERAHUB_FROM_EMAIL', "noreply@camerahub.info")
SERVER_EMAIL = DEFAULT_FROM_EMAIL
EMAIL_BACKEND = os.getenv('CAMERAHUB_EMAIL_BACKEND', 'django.core.mail.backends.filebased.EmailBackend')

if EMAIL_BACKEND == 'django.core.mail.backends.smtp.EmailBackend':
    EMAIL_USE_TLS = os.getenv('CAMERAHUB_EMAIL_USE_TLS')
    EMAIL_USE_SSL = os.getenv('CAMERAHUB_EMAIL_USE_SSL')
    EMAIL_HOST = os.getenv('CAMERAHUB_EMAIL_HOST')
    EMAIL_HOST_USER = os.getenv('CAMERAHUB_EMAIL_HOST_USER')
    EMAIL_HOST_PASSWORD = os.getenv('CAMERAHUB_EMAIL_HOST_PASSWORD')
    EMAIL_PORT = os.getenv('CAMERAHUB_EMAIL_PORT')
elif EMAIL_BACKEND == 'sendgrid_backend.SendgridBackend':
    SENDGRID_API_KEY = os.getenv('CAMERAHUB_SENDGRID_KEY')
elif EMAIL_BACKEND == 'django.core.mail.backends.filebased.EmailBackend':
    EMAIL_FILE_PATH = os.path.join(BASE_DIR, "sent_emails")

ACCOUNT_ACTIVATION_DAYS = 7  # One-week activation window
REGISTRATION_OPEN = True  # allow sign-ups

# Required for django.contrib.sites
DEFAULT_SITE_ID = 1
SITE_ID = 1

#AUTH_USER_MODEL = 'schema.User'

# Emit logs of WARNING and above to stderr
# for both production and debug mode
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'console2': {
            'class': 'logging.StreamHandler',
        },
    },
    'loggers': {
        'django': {
            'handlers': ['console2'],
            'level': os.getenv('DJANGO_LOG_LEVEL', 'WARNING'),
        },
    },
}

if os.getenv('CAMERAHUB_MEMCACHED') == 'true':
    CACHES = {
        'default': {
            'BACKEND': 'speedinfo.backends.proxy_cache',
            'CACHE_BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',
            'LOCATION': f"{os.getenv('CAMERAHUB_MEMCACHED_HOST', '127.0.0.1')}:{os.getenv('CAMERAHUB_MEMCACHED_PORT', '11211')}"
        }
    }
else:
    CACHES = {
        'default': {
            'BACKEND': 'speedinfo.backends.proxy_cache',
            'CACHE_BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
        }
    }

TAGGIT_CASE_INSENSITIVE = True

# Use OpenStreetMap instead of Google for form widget
GEOPOSITION_BACKEND = 'leaflet'

REST_FRAMEWORK = {
    'DEFAULT_PAGINATION_CLASS': 'rest_framework.pagination.PageNumberPagination',
    'PAGE_SIZE': 10,
    'DEFAULT_FILTER_BACKENDS': ['django_filters.rest_framework.DjangoFilterBackend']
}

DBBACKUP_STORAGE = 'django.core.files.storage.FileSystemStorage'
DBBACKUP_STORAGE_OPTIONS = {'location': os.path.join(BASE_DIR, "backup")}
DBBACKUP_CONNECTORS = {
    'default': {
        'USER': os.getenv('CAMERAHUB_DB_USER'),
        'PASSWORD': os.getenv('CAMERAHUB_DB_PASS'),
        'HOST': os.getenv('CAMERAHUB_DB_HOST'),
        'CONNECTOR': 'dbbackup.db.postgresql.PgDumpBinaryConnector',
    }
}

# django-star-ratings
STAR_RATINGS_ANONYMOUS = False

# drf-generators
REST_FRAMEWORK = {
    'DEFAULT_PAGINATION_CLASS': 'rest_framework.pagination.PageNumberPagination',
    'PAGE_SIZE': 25
}

# speedinfo
SPEEDINFO_STORAGE = 'speedinfo.storage.database.storage.DatabaseStorage'

# status URL
STATUS_URL = os.getenv('CAMERAHUB_STATUS_URL')

# django-settings-export
# These settings are exposed to template context
SETTINGS_EXPORT = [
    'STATUS_URL',
]

# Sphinx
SPHINXDOC_BASE_TEMPLATE = 'docs.html'
HAYSTACK_CONNECTIONS = {
    'default': {
        'ENGINE': 'haystack.backends.simple_backend.SimpleEngine',
    },
}



from django.db import migrations

def closest_focus_lensmodel(apps, schema_editor):
    lensmodel = apps.get_model('schema', 'LensModel')
    for row in lensmodel.objects.filter(closest_focus__isnull=False):
        row.closest_focus = row.closest_focus / 100
        row.save()

def closest_focus_cameramodel(apps, schema_editor):
    cameramodel = apps.get_model('schema', 'CameraModel')
    for row in cameramodel.objects.filter(closest_focus__isnull=False):
        row.closest_focus = row.closest_focus / 100
        row.save()

class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0062_auto_20200529_2059'),
    ]

    operations = [
        migrations.RunPython(closest_focus_lensmodel),
        migrations.RunPython(closest_focus_cameramodel),
    ]



# Generated by Django 2.2.9 on 2020-03-05 10:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0024_cameramodel_shoe'),
    ]

    operations = [
    ]



import glob
import os
import shutil
from pathlib import Path
from django.core.management.base import BaseCommand

class Command(BaseCommand):
    help = 'Generates sets of icons for CameraHub'

    def handle(self):

        # Set up mappings between old and new icon names.
        # One source SVG can be mapped to multiple destination SVGs
        newnames = {
            'icons8-camera-addon': ['accessory'],
            'icons8-collectibles': ['archive'],
            'icons8-battery': ['battery'],
            'icons8-video-trimming': ['bulkfilm'],
            'icons8-camera': ['camera'],
            'icons8-camera-identification': ['condition'],
            'icons8-volume': ['developer'],
            'icons8-industrial-scales': ['enlarger'],
            'icons8-easel': ['exhibition'],
            'icons8-medium-icons': ['exposureprogram'],
            'icons8-film-roll': ['film'],
            'icons8-360-degrees': ['filter'],
            'icons8-camera-flash': ['flash'],
            'icons8-resolution': ['format'],
            'icons8-lens': ['lens'],
            'icons8-factory': ['manufacturer'],
            'icons8-slr-small-lens': ['mount'],
            'icons8-metamorphose': ['mountadapter', 'misc'],
            'icons8-movie': ['negative'],
            'icons8-surface': ['negativesize'],
            'icons8-transaction-list': ['order'],
            'icons8-sheets': ['paperstock'],
            'icons8-user': ['person'],
            'icons8-xlarge-icons': ['print'],
            'icons8-lab-items': ['process'],
            'icons8-jpg': ['scan'],
            'icons8-exposure': ['shutterspeed'],
            'icons8-small-lens': ['teleconverter'],
            'icons8-test-tube': ['toner'],
            'icons8-home': ['home'],
            'icons8-facebook': ['facebook'],
            'icons8-github': ['github'],
            'icons8': ['icons8'],
            'icons8-about': ['about'],
            'icons8-login': ['login'],
            'icons8-add-user-male': ['register'],
            'icons8-sign-in-form-password': ['password'],
            'icons8-bar-chart': ['stats'],
            'icons8-help': ['help'],
            'icons8-edit': ['edit'],
            'icons8-add': ['add'],
            'icons8-cancel': ['no'],
            'icons8-ok': ['yes'],
            'icons8-search-more': ['search'],
            'icons8-price-tag': ['tag'],
            'icons8-ios': ['history'],
            'icons8-color-wheel': ['colour'],
            'icons8-color-wheel-mono': ['bw'],
            'icons8-true-false': ['features'],
            'icons8-weight': ['weight'],
            'icons8-focal-length': ['optics'],
            'icons8-width': ['focus'],
            'icons8-voltmeter': ['meter'],
            'icons8-aperture': ['shutter'],
            'icons8-fast-forward': ['next'],
            'icons8-envelope': ['mail'],
            'icons8-google-plus': ['googleplus'],
            'icons8-reddit': ['reddit'],
            'icons8-twitter': ['twitter'],
            'icons8-vintage-camera': ['vintagecamera'],
            'icons8-slr-camera': ['bigcamera'],
            'icons8-ruler': ['ruler'],
            'icons8-receive-cash': ['ownership'],
            'icons8-overview': ['summary'],
            'icons8-diversity': ['compatibility'],
            'icons8-up': ['up'],
            'icons8-down': ['down'],
            'icons8-expired': ['expired'],
            'icons8-place-marker': ['location'],
            'icons8-rest-api': ['api'],
            'icons8-25-': ['percent'],
            'icons8-heart-monitor': ['status'],
        }

        # Define input directory, relative to ./manage.py
        input_dir = 'icons/svg'

        # Define output directory, relative to ./manage.py
        output_dir = 'schema2/static/svg'

        # Get list of SVGs
        files = glob.glob(input_dir + "/*.svg")

        # Delete and recreate the output dir
        shutil.rmtree(output_dir)
        os.mkdir(output_dir)

        for file in files:

            # Parse filename
            barename = Path(file).stem
            barename = barename.replace('-500', '')


            if barename in newnames.keys():
                # We found the file in the mapping
                for mapping in newnames.get(barename):
                    shutil.copyfile(file, f"{output_dir}/{mapping}.svg")
                    self.stdout.write(self.style.SUCCESS(f"generated {output_dir}/{mapping}.svg"))
            else:
                self.stdout.write(self.style.WARNING(f"{file} is not needed"))



from math import degrees
from itertools import chain, count
from re import match
from django.utils.safestring import mark_safe
from numpy import arctan


def boolicon(obj):
    img = '<img src="/static/svg/{}.svg" width="30" height="30" alt="{}" title="{}">'
    if obj is not None:
        if bool(obj):
            return_value = mark_safe(img.format('yes', 'Yes', 'Yes'))  # pylint: disable=consider-using-f-string
        else:
            return_value = mark_safe(img.format('no', 'No', 'No'))  # pylint: disable=consider-using-f-string
    else:
        return_value = None

    return return_value


def colouricon(obj):
    img = '<img src="/static/svg/{}.svg" width="30" height="30" alt="{}" title="{}">'
    if obj is not None:
        if bool(obj):
            return_value = mark_safe(img.format('colour', 'Colour', 'Colour'))  # pylint: disable=consider-using-f-string
        else:
            return_value = mark_safe(img.format('bw', 'Black & White', 'Black & White'))  # pylint: disable=consider-using-f-string
    else:
        return_value = None

    return return_value


def locationicon(obj):
    img = '<img src="/static/svg/{}.svg" width="30" height="30" alt="{}" title="{}">'
    if obj is not None:
        if bool(obj):
            return_value = mark_safe(img.format('location', 'Location', 'Location'))  # pylint: disable=consider-using-f-string
        else:
            return_value = 'None'
    else:
        return_value = None

    return return_value


def angle_of_view(diag, focal):
    # fov = 2 arctan (d / 2f)
    if diag is not None and focal is not None:
        angle = round(degrees(2 * arctan(float(diag) / (2*float(focal)))))
    else:
        angle = None
    return angle


def to_dict(instance):
    opts = instance._meta
    data = {}
    for field in chain(opts.concrete_fields, opts.private_fields):
        data[field.name] = field.value_from_object(instance)
    for field in opts.many_to_many:
        data[field.name] = [i.id for i in field.value_from_object(instance)]
    return data


def canondatecode(datecode, introduced=1960, discontinued=2100):
    """Decode Canon datecodes to discover the year of manufacture. Datecodes are sometimes ambiguous so by passing in the dates
    that the model was introduced and discontinued, the year of manufacture can be pinned down
    """

    # While there are non-None defaults for these values in this function, the calling code
    # always passes the variable, even if it is None. So passing in None will override the default
    # value at the top of the function. So here we check for None values and set a default if necessary.
    if introduced is None:
        introduced = 1960

    if discontinued is None:
        discontinued = 2100

    # Initialise empty list of candidate dates
    guesses = []

    # AB1234, B1234A, B123A
    # From 1960-2012, the date code is in the form of "AB1234". "A" indicates the factory. Prior to 1986, "A" is moved to the end.
    # "B" is a year code that indicates the year of manufacture. Canon increments this letter each year starting with A in 1960
    # Of the 4 digits, the first two are the month of manufacture. Sometimes the leading 0 is omitted.
    oldstyle = match(r"^[A-Z]?([A-Z])[0-9]{3,4}[A-Z]?$", datecode.upper())

    # From 2008, the date code is 10 digits. The first two correspond to the year & month of manufacture.
    # From 2008-2012 the month code runs from 38-97. In 2013, it is reset to 01. These are treated as different epochs.
    newstyle = match(r"^(\d{2})\d{8}$", datecode.upper())

    if oldstyle:
        dateletter = oldstyle.group(1)
        epochstart = 1960
        epochend = 2012

        # Calculate datenumber as years since epoch
        datenumber = ord(dateletter) - ord('A')

        # Find all years within an epoch that a letter could represent
        for i in count(0):
            guess = epochstart + datenumber + i*26

            # Stop if we go above the end date of the datecode epoch
            if guess > epochend:
                break

            # Add our guess to the list
            guesses.append(guess)
            print(guess)

    elif newstyle:
        datenumber = newstyle.group(1)

        # First epoch
        if 38 <= datenumber <= 97:
            epochstart = 2008
            epochend = 2012
            start = 38

            guess = epochstart + int((datenumber - start) / 12)
            guesses.append(guess)

        # Second epoch
        else:
            epochstart = 2013
            epochend = 2100
            start = 1

            # Find all years within an epoch that a letter could represent
            for i in count(0):
                guess = epochstart + int(((datenumber + i*100) - start) / 12)
                if guess > epochend:
                    break
                guesses.append(guess)

	# Now examine our guesses for plausibility based on when the lens was released & discontinued
    plausible = []
    for guess in guesses:
        # Skip if our guess is before the lens was introduced
        if guess < introduced:
            continue
        # Stop if our guess is after the lens was discontinued
        if guess > discontinued:
            continue
        plausible.append(guess)

    # If we narrowed it down to one year, return that. Otherwise, return nothing.
    if len(plausible) == 1:
        year = plausible[0]
    else:
        year = None

    return year
